%clc; clear; close all; 

%Discretisized time step
%Ts = 50e-6;
Ts = 2.5e-6;
f_sw = 15e3;

%%Parameters
V_LN = 400/sqrt(3); %Line-neutral
V_LL = V_LN*sqrt(3); 
V_DC = 750;
f = 50; %Hz
w_base = 2*pi*f;
w = 2*pi*50;
P_rated = 10e3;
Q_rated = 10e3;
w_f = 2*pi*5;
%w_f = 2*pi*10;
T_LPF = 1/w_f; %s, time constant for power LP filter

V_max = 1.05*V_LN; %V_max at open circuit
V_min = 0.95*V_LN;
w_max = 1.005*w;
w_min = 0.995*w;

%Droop coefficients
DeltaW = 0.005;
DeltaV = 0.05;
n_p = DeltaW*w/P_rated; %P-f
n_q = DeltaW*w/Q_rated; %Q-f
m_p = DeltaV*V_max/P_rated; %P-V
m_q = DeltaV*V_max/Q_rated; %Q-V


%Load
P_load = 1.5*P_rated;
Q_load = 0*Q_rated;


%Filter as calculated by "LCL filter design" when P_rated = 10e3 W
L_c = 5.082e-4;
R_c = 0.3e-3;
C_f = 3.01e-5;
L_g = 3.05e-4;
R_g = 0.2e-3;
R_d = 0.84;

%DC side
C_d = 2000e-6;
L_d = 8.29e-4;

%Line
R_line1 = 2*0.397; %Ohm/km from CIGRE benchmark LV microgird
X_line1 = 2*0.279; %Ohm/km from CIGRE benchmark LV microgird
L_line1 = X_line1/w;


% Power references made to have the frequency equal to reference frequency
% %Reference values
P_ref_1 = 0*P_load/2;
Q_ref_1 = 0*Q_load/2;
P_ref_2 = 0*P_load/2;
Q_ref_2 = 0*Q_load/2;


%% Tuning the current control
w_0i = 2*pi*f_sw/10; %Bandwith of the current controller = 1/10 of the switching frequency
rho = 1.1; %Damping coefficient
Kp_i = 2*rho*w_0i*L_c - R_c; %Proportional gain in current controller
Ki_i = w_0i^2*L_c; %Integral gain of current controller
V_filt = 1000; %1/timeconstant for filtering the voltage at the capacitor.

% % %Bode plots
% s = tf('s');
% Hsys_c = (1/L_c)/(s + R_c/L_c);%*1/(1+s*T_small);
% Hpi_c = Kp_i + Ki_i/s;
% H_OL_c = Hsys_c*Hpi_c;
% H_CL_c = H_OL_c/(1 + H_OL_c);
% margin(H_OL_c)
% set(gcf, 'Units', 'Normalized', 'OuterPosition', [0.2, 0.3, 0.5, 0.5]);
% set(findall(gcf,'type','line'),'linewidth',2)

%% Tuning the voltage controller
w_0v = w_0i/10; %Bandwidth of the voltage controller 
Kp_v = 2*rho*w_0v*C_f; %Proportional gain in voltage controller
Ki_v = w_0v^2*C_f; %Integral gain in voltage controller

% % %Bode plots
% s = tf('s');
% figure()
% Hsys_v = (1/C_f)/(s); %*1/(1+s*T_eq);
% Hpi_v = Kp_v + Ki_v/s;
% H_OL_v = Hsys_v*Hpi_v;
% H_CL_v = H_OL_v/(1 + H_OL_v);
% margin(H_OL_v)
% set(gcf, 'Units', 'Normalized', 'OuterPosition', [0.2, 0.3, 0.5, 0.5]);
% set(findall(gcf,'type','line'),'linewidth',2)
% 


%Base values
V_base = V_LN;
S_base = P_rated;
I_base = S_base/3/V_base;
% Z_base = V_base/I_base;
% L_base = Z_base/w_base;
% C_base = 1/(Z_base*w_base);


