%clc; clear; close all;

Ts = 2.5e-6; %Time step in simulation
t_switch = 1.0;
f_sw = 15e3;


%Parameters
V_LL = 400; %Line-Line
V_LN = V_LL/sqrt(3); 
V_DC = 750;
f = 50; %Hz
w_base = 2*pi*f;
w = w_base;
P_rated = 10e3; %Per inverter
Q_rated = 10e3;

V_max = 1.05*V_LN;
V_min = 0.95*V_LN;
w_max = 1.005*w;
w_min = 0.995*w;
%Gain
V_gain = V_max;
%V_gain = V_LN;
I_gain = 3*V_min/Q_rated;

%Conventional or opposite droop
Phi = pi/2; %Select 0 for opposite droop (P-V, Q-f) or pi/2 for regular droop (Q-V, P-f)

%Droop coefficients translated into VOC parameters
DeltaW = 0.005;
%DeltaW = 2*DeltaW;
DeltaV = 0.05;
if Phi == 0
    n_q = DeltaW*w/Q_rated; %Q-f
    m_p = DeltaV*V_max/P_rated;
    n = n_q;
    m = m_p;
elseif Phi == pi/2
    n_p = DeltaW*w/P_rated; %P-f
    m_q = DeltaV*V_max/Q_rated; %Q-V
    n = n_p;
    m = m_q;
end

%VOC parameters depending on the definition of the V_gain. 
% 09.05: These are found to be equivalent so it does not matter what V_gain
% is in this case.
if V_gain == V_LN
    sigma = 1/m * I_gain/(6*1.05);
    C = 1/n * I_gain/(6*1.05^2*V_gain);
    alpha = 2*sigma/3/(1.05^2);
else
    sigma = 1/m * I_gain/6;
    C = 1/n * I_gain/(6*V_gain);
    alpha = 2*sigma/3;
end
L = 1/(C*(w)^2);
epsilon = sqrt(L/C)


%Load
P_load = 0.5*P_rated;
Q_load = 0*Q_rated;

% %Filter as calculated by "LCL filter design" when P_rated = 10e3 W
L_c = 5.082e-4;
R_c = 0.3e-3;
C_f = 3.01e-5;
L_g = 3.05e-4;
R_g = 0.2e-3;
R_d = 0.84;

%DC side
C_d = 2000e-6;
L_d = 8.29e-4;

%Line
R_line1 = 2*0.397; %Ohm/km from CIGRE benchmark LV microgird
X_line1 = 2*0.279; %Ohm/km from CIGRE benchmark LV microgird
L_line1 = X_line1/w_base;

        
%f_res = 1/2/pi*sqrt(L_c+(L_g+L_line1)/(L_c*(L_g+L_line1)*C_f))  

%Base values
V_base = V_LN;
S_base = P_rated;
I_base = S_base/3/V_base;


T_LPF = 1/(2*pi*5); %s, time constant for power measurement LP filter

